All pastes #827405 Raw Edit

Mine

public text v1 · immutable
#827405 ·published 2007-12-21 19:13 UTC
rendered paste body
ApplianceKit 0.3.17-0dereferenced1
Copyright (c) 2006-2008 Dereferenced Technologies, Ltd.
Licensed under the GPL version 2! NO WARRANTY!

Essential Options:
	--identity, -I
		Prints the ApplianceKit identity metadata. This is
		equivilant to calling lsb_release -a.

	--curse, -C
		Updates troves in the Appliance to the specified
		manifest; or the currently selected manifest if
		only an update is requested. Unlike --update,
		ApplianceKit will make a backup of your system,
		which you can revert to using --uncurse.

	--build, -B
		Builds a new set of troves for a new appliance.
		See the ApplianceKit manpage for information about
		making derivitives.

	--uncurse
		Reverts back to the last known good state. This
		state is set when upgrading by using --curse instead
		of --upgrade.

	--upgrade, -U
		Upgrades to the latest trove updates, or to an
		entirely new Manifest. --curse is recommended when
		performing distribution updates; read the manpage
		for why.

	--status, -s
		Displays the status of any pending ApplianceKit
		transactions.

	--deploy
		Builds installation media or a virtual machine of the
		Appliance. You will need --method and --manifest for
		this option.

		If --manifest is not used, ApplianceKit will build
		distribution media based on what you have in your
		local system. You probably do not want that.

	--manifest [manifest]
		Selects the Manifest to perform transactions on.

	--method [method]
		Selects what method to use to satisfy the requirements
		of --deploy. Available methods are:

		xen: Builds a Xen domain.
		vmx: Builds a VMware image.
		iso: Builds a CD or DVD ISO image, depending on amount
		     of packages in the Appliance Manifest.

System manifest is: com.ubuntu.release.hardy

Report bugs to <http://bugzilla.dereferenced.org>.